@@ -1,6 +1,7 @@
 from datetime import datetime
 from xml.etree import ElementTree as etree
 
+
 class OfxWriter(object):
     statement = None
     tb = None
@@ -85,7 +86,7 @@ class OfxWriter(object):
 
         tb.start("LEDGERBAL", {})
         self.buildAmount("BALAMT", self.statement.end_balance, False)
-        self.buildDateTime("DTASOF" , self.statement.end_date, False)
+        self.buildDateTime("DTASOF", self.statement.end_date, False)
         tb.end("LEDGERBAL")
 
         tb.end("STMTRS")
@@ -96,7 +97,7 @@ class OfxWriter(object):
         tb = self.tb
         tb.start("STMTTRN", {})
 
-        self.buildText("TRNTYPE", "CHECK")  # TODO: fix
+        self.buildText("TRNTYPE", line.trntype)
         self.buildDate("DTPOSTED", line.date)
         self.buildDate("DTUSER", line.date_user)
         self.buildAmount("TRNAMT", line.amount)
@@ -104,11 +105,11 @@ class OfxWriter(object):
         self.buildText("CHECKNUM", line.check_no)
         self.buildText("NAME", line.payee)
         self.buildText("MEMO", line.memo)
+        self.buildText("REFNUM", line.refnum)
         #self.buildText("CURRENCY", line.currency)
 
         tb.end("STMTTRN")
 
-
     def buildText(self, tag, text, skipEmpty=True):
         if not text and skipEmpty:
             return
